<?php
/**
 * @package     Joomla.Site
 * @subpackage  com_easytagcloud
 * @copyright   Copyright (C) 2015 http://www.huangqiprojects.com. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

/**
 * Tags Component Route Helper
 *
 * @static
 * @package     Joomla.Site
 * @subpackage  com_tags
 * @since       3.1
 */
class EasyTagCloudHelperRoute extends JHelperRoute
{
	protected static $lookup;

	/**
	 * Tries to load the router for the component and calls it. Otherwise uses getTagRoute.
	 *
	 * @param   integer  $contentItemId     Component item id
	 * @param   string   $contentItemAlias  Component item alias
	 * @param   integer  $contentCatId      Component item category id
	 * @param   string   $language          Component item language
	 * @param   string   $typeAlias         Component type alias
	 * @param   string   $routerName        Component router
	 *
	 * @return  string  URL link to pass to JRoute
	 *
	 * @since   3.1
	 */
	public static function getItemRoute($contentItemId, $contentItemAlias, $contentCatId, $language, $typeAlias, $routerName)
	{
		$link = '';
		$explodedAlias = explode('.', $typeAlias);
		$explodedRouter = explode('::', $routerName);
		if (file_exists($routerFile = JPATH_BASE . '/components/' . $explodedAlias[0] . '/helpers/route.php'))
		{
			JLoader::register($explodedRouter[0], $routerFile);
			$routerClass = $explodedRouter[0];
			$routerMethod = $explodedRouter[1];
			if (class_exists($routerClass) && method_exists($routerClass, $routerMethod))
			{
				if ($routerMethod == 'getCategoryRoute')
				{
					$link = $routerClass::$routerMethod($contentItemId, $language);
				}
				else
				{
					$link = $routerClass::$routerMethod($contentItemId . ':' . $contentItemAlias, $contentCatId, $language);
				}
			}
		}
		if ($link == '')
		{
			// create a fallback link in case we can't find the component router
			$router = new JHelperRoute;
			$link = $router->getRoute($contentItemId, $typeAlias, $link, $language, $contentCatId);
		}
		return $link;
	}

	public static function getTagRoute($id, $mid)
	{
		$needles = array(
			'tag'  => array((int) $id)
		);
		if ($id < 1)
		{
			$link = '';
		}
		else
		{
			// detect the tag page
			$app = JFactory::getApplication();
			$menus		= $app->getMenu('site');
			$component	= JComponentHelper::getComponent('com_easytagcloud');
			$items		= $menus->getItems('component_id', $component->id);
			// we only need the first menu item
			$item = $items[0];
			$itemid = '';
			if ($items) {
				foreach ($items as $item) {
					if (isset($item->query) && isset($item->query['view']) && $item->query['view'] == 'tag') {
						$itemid = '&Itemid='.$item->id;
						break;
					}
				}
			}
			$mid = isset($mid) ? '&mid='.$mid : '';
			// Create the link
			$link = 'index.php?option=com_easytagcloud&view=tag&id=' . $id . $mid . $itemid;
		}

		return $link;
	}

}
