<?php
/**
 * @package     Joomla.Site
 * @subpackage  com_easytagcloud
 * @copyright   Copyright (C) 2015 http://www.huangqiprojects.com. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

/**
 * EasyTagCloud Component Tag Model
 *
 * @package     Joomla.Site
 * @subpackage  com_easytagcloud
 * @since       2.8
 */
class EasyTagCloudModelTag extends JModelList
{
	/**
	 * The tags that apply.
	 *
	 * @var    object
	 * @since  3.1
	 */
	protected $tag = null;

	/**
	 * The list of items associated with the tags.
	 *
	 * @var    array
	 * @since  3.1
	 */
	protected $items = null;
    
	/**
	 * Constructor.
	 *
	 * @param   array  An optional associative array of configuration settings.
	 * @see     JController
	 * @since   3.1
	 */
	public function __construct($config = array())
	{
		if (empty($config['filter_fields']))
		{
			$config['filter_fields'] = array(
				'core_content_id', 'c.core_content_id',
				'core_title', 'c.core_title',
				'core_type_alias', 'c.core_type_alias',
				'core_checked_out_user_id', 'c.core_checked_out_user_id',
				'core_checked_out_time', 'c.core_checked_out_time',
				'core_catid', 'c.core_catid',
				'core_state', 'c.core_state',
				'core_access', 'c.core_access',
				'core_created_user_id', 'c.core_created_user_id',
				'core_created_time', 'c.core_created_time',
				'core_modified_time', 'c.core_modified_time',
				'core_ordering', 'c.core_ordering',
				'core_featured', 'c.core_featured',
				'core_language', 'c.core_language',
				'core_hits', 'c.core_hits',
				'core_publish_up', 'c.core_publish_up',
				'core_publish_down', 'c.core_publish_down',
				'core_images', 'c.core_images',
				'core_urls', 'c.core_urls',
				'match_count',
			);
		}

		parent::__construct($config);
	}

	/**
	 * Method to get a list of items the tag.
	 *
	 * @return  mixed  An array of objects on success, false on failure.
	 *
	 * @since   3.1
	 */
	public function getItems()
	{
		// Invoke the parent getItems method to get the main list
		
		$items = parent::getItems();
		if (!empty($items))
		{
			foreach ($items as $item)
			{
				$explodedTypeAlias = explode('.', $item->type_alias);
				$item->link = 'index.php?option=' . $explodedTypeAlias[0] . '&view=' . $explodedTypeAlias[1] . '&id=' . $item->content_item_id . ':' . $item->core_alias;
				// Get display date
				switch ($this->state->params->get('tag_list_show_date'))
				{
					case 'modified':
						$item->displayDate = $item->core_modified_time;
						break;

					case 'created':
						$item->displayDate = $item->core_created_time;
						break;

					default:
					case 'published':
						$item->displayDate = ($item->core_publish_up == 0) ? $item->core_created_time : $item->core_publish_up;
						break;
				}
			}
			return $items;
		}
		else
		{
			return false;
		}
	}
	
	

	/**
	 * Method to build an SQL query to load the list data of all items with a given tag.
	 *
	 * @return  string  An SQL query
	 *
	 * @since   3.1
	 */
	protected function getListQuery()
	{

		$tagId  = $this->getState('tag.id') ? : '';

		$orderByOption = $this->getState('list.ordering', 'c.core_title');
		$orderDir = $this->getState('list.direction', 'ASC');
		$language = $this->getState('tag.language');
		$stateFilter = $this->getState('tag.state');

	    // Optionally filter on language
		if (empty($language))
		{
			$language = JComponentHelper::getParams('com_easytagcloud')->get('tag_list_language_filter', 'all');
		}
		$tagsHelper = new JHelperTags;
		$query = $tagsHelper->getTagItemsQuery($tagId, null, false, $orderByOption, $orderDir, 1, $language, $stateFilter);
		
		if ($this->state->get('list.filter'))
		{
			$query->where($this->_db->quoteName('c.core_title') . ' LIKE ' . $this->_db->quote('%' . $this->state->get('list.filter') . '%'));
		}
		
		// categories filter, since v2.8
		$app = JFactory::getApplication('site');
		$db = JFactory::getDbo();			
		$mid = $app->input->get('mid', '0', 'int');
		$sql = $db->getQuery(true)
		    ->select('params')
			->from('#__modules AS m')
			->where('m.id = ' . $mid);
	    $db->setQuery($sql);
		$module = $db->loadObject();
		$categoriesfilter = json_decode($module->params)->categoriesfilter; 
		if (!empty($categoriesfilter)) {
			$types = Array();
			$catids = Array();
			foreach ($categoriesfilter as $c) {
			         $tmp = explode(".", $c);
					 $types[] = "'".$tmp[0]."'";
					 $catids[] = $tmp[1];
			}

		    $types = implode(',', $types);
		    $catids = implode(',', $catids);			

			$query->where('SUBSTRING_INDEX(c.core_type_alias, ".", 1)' . ' IN (' . $types . ')');	
			$query->where($db->quoteName('c.core_catid') . ' IN (' . $catids . ')');			
			//echo  $query->__toString(); 
		    //exit;		
			
		} 
		return $query;
	}

	/**
	 * Method to auto-populate the model state.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @param   string  $ordering   An optional ordering field.
	 * @param   string  $direction  An optional direction (asc|desc).
	 *
	 * @return  void
	 *
	 * @since   3.1
	 */
	protected function populateState($ordering = 'c.core_title', $direction = 'ASC')
	{
		$app = JFactory::getApplication('site');

		// Load the parameters.
		$params = $app->getParams();
		$this->setState('params', $params);

		// Load state from the request.
		$id = $app->input->get('id', '', 'string');

		$this->setState('tag.id', (int)$id);

		$language = $app->input->getString('tag_list_language_filter');
		$this->setState('tag.language', $language);
		$limit = $app->getUserStateFromRequest('global.list.limit', 'limit', $app->get('list_limit'), 'uint');
		

		$this->setState('list.limit', $limit);

		$offset = $app->input->get('limitstart', 0, 'uint');
		$this->setState('list.start', $offset);

		$itemid = (int)$id . ':' . $app->input->get('Itemid', 0, 'int');
		$orderCol = $app->getUserStateFromRequest('com_easytagcloud.tag.list.' . $itemid . '.filter_order', 'filter_order', '', 'string');
		$orderCol = !$orderCol ? $this->state->params->get('tag_list_orderby', 'c.core_title') : $orderCol;

		if (!in_array($orderCol, $this->filter_fields))
		{
			$orderCol = 'c.core_title';
		}

		$this->setState('list.ordering', $orderCol);

		$listOrder = $app->getUserStateFromRequest('com_easytagcloud.tag.list.' . $itemid . '.filter_order_direction', 'filter_order_Dir', '', 'string');
		$listOrder = !$listOrder ? $this->state->params->get('tag_list_orderby_direction', 'ASC') : $listOrder;

		if (!in_array(strtoupper($listOrder), array('ASC', 'DESC', '')))
		{
			$listOrder = 'ASC';
		}

		$this->setState('list.direction', $listOrder);

		$this->setState('tag.state', 1);

		// Optional filter text
		$filterSearch = $app->getUserStateFromRequest('com_easytagcloud.tag.list.' . $itemid . '.filter_search', 'filter-search', '', 'string');
		$this->setState('list.filter', $filterSearch);
	}

	/**
	 * Method to get tag data for the current tag
	 *
	 * @param   integer  An optional ID
	 *
	 * @return  object
	 * @since   3.1
	 */
	public function getItem($id = null)
	{
		if (!isset($this->item) ||$this->item === null)
		{
			$this->item = false;
			if (empty($id))
			{
				$id = $this->getState('tag.id');
			}

			require_once(JPATH_ADMINISTRATOR . '/components/com_tags/tables/tag.php');
			// Get a level row instance.
			$table = JTable::getInstance('Tag', 'TagsTable');
			// Attempt to load the rows into an array.
			try
			{
				$table->load($id);
				// Check published state.
				if ($published = $this->getState('filter.published'))
				{
					if ($table->published != $published)
					{
						return $this->item;
					}
				}

				// Convert the JTable to a clean JObject.
				$properties = $table->getProperties(1);
				$this->item = JArrayHelper::toObject($properties, 'JObject');
			}
			catch (RuntimeException $e)
			{
				$this->setError($e->getMessage());
				return false;
			}
			
		}
		return $this->item;
	}

	public function getTotal()
	{ 
	   return parent::getTotal();
	}
}